@@ -199,6 +199,11 @@ function centerObject(fc){
     });
   }
   catch(err){
+    try{
+      fc.bounds().evaluate(function(feature){synchronousCenterObject(feature);
+    })}catch(err){
+      console.log(err);
+    }
     console.log(err);
   }
 }
@@ -216,6 +221,8 @@ function convertToGeoJSON(formID){
   var url = 'https://ogre.adc4gis.com/convert'
 
   var data = new FormData();
+  // data.append("sourceSrs","EPSG:5070");
+   
   data.append("targetSrs","EPSG:4326");
   jQuery.each(jQuery('#'+formID)[0].files, function (i, file) {
     data.append("upload", file);
@@ -225,11 +232,44 @@ function convertToGeoJSON(formID){
     url: url,
     data: data,
     processData: false,
-    contentType: false
+    contentType: false,
+    error: function (err) {
+        // console.log("AJAX error in request: " + JSON.stringify(err, null, 2));
+        showMessage('Error!', 'Error converting file: <hr>'+err.responseJSON.msg.replace('\n','<br>'));
+        $('#summary-spinner').hide();
+    }
   });
   return out;
 }
-
+function compressGeoJSON(geoJSON,reductionFactor){
+  if(reductionFactor === undefined || reductionFactor === null){reductionFactor = 2}
+  geoJSON.features = geoJSON.features.map(function(f){
+    
+    if(f.geometry.type.indexOf('Multi')> -1){
+      f.geometry.coordinates = f.geometry.coordinates.map(function(poly){
+        return poly.map(function(pts){
+          if(pts.length>100){
+            pts = pts.filter((element, index) => {return index % reductionFactor === 0;})
+          }
+          return pts//.map(function(pt){
+          //   return [parseFloat(pt[0].toFixed(decimalPlaces)),parseFloat(pt[1].toFixed(decimalPlaces))]
+          // })
+        })
+      })
+    }else{
+      f.geometry.coordinates = f.geometry.coordinates.map(function(poly){
+        if(poly.length>100){
+          poly = poly.filter((element, index) => {return index % reductionFactor === 0;});
+        }
+        return poly//.map(function(pt){
+          // return [parseFloat(pt[0].toFixed(decimalPlaces)),parseFloat(pt[1].toFixed(decimalPlaces))]
+        // })
+      })
+    }
+   return f
+  })
+  return geoJSON
+}
 //////////////////////////////////////////////////////
 //Wrappers for printing and printing to console
 function printImage(message){print(message)};
@@ -556,7 +596,9 @@ function jitterZoom(fromButton){
     // console.log(tDiff)
     console.log('jittering zoom')
     var z = map.getZoom();
+    updateViewList = false;
     map.setZoom(z-1);
+    updateViewList = false;
     map.setZoom(z);
     jittered = true;
     lastJitter = new Date();
@@ -639,7 +681,8 @@ function addTimeLapseToMap(item,viz,name,visible,label,fontColor,helpBox,whichLa
     //Force time lapses to be turned off on load to speed up loading
     var visible = false;
   if(viz.opacity === undefined || viz.opacity === null){viz.opacity = 1}
-   
+  item = ee.ImageCollection(item);
+
   var checked = '';
   if(visible){checked = 'checked'}
   var legendDivID = name.replaceAll(' ','-')+ '-' +NEXT_LAYER_ID.toString() ;
@@ -647,6 +690,14 @@ function addTimeLapseToMap(item,viz,name,visible,label,fontColor,helpBox,whichLa
   legendDivID = legendDivID.replaceAll('(','-');
   legendDivID = legendDivID.replaceAll(')','-');
   
+  //AutoViz if specified
+  if(viz.autoViz){
+    dicts =getLookupDicts(ee.Image(item.first()),null,'eeImage')
+    viz.classLegendDict = dicts.classLegendDict;
+    viz.queryDict = dicts.queryDict;
+    viz.autoViz = false;
+  }
+  
   viz.canQuery = false;
   viz.isSelectLayer = false;
   viz.isTimeLapse = true;
@@ -667,12 +718,14 @@ function addTimeLapseToMap(item,viz,name,visible,label,fontColor,helpBox,whichLa
   //Assumes the provided image collection has time property under system:time_start property
   if(viz.years === null || viz.years === undefined){
     console.log('start computing years');
-    viz.years = item.sort('system:time_start',true).toList(10000,0).map(function(img){
+    viz.years = unique(item.sort('system:time_start',true).toList(10000,0).map(function(img){
       var d = ee.Date(ee.Image(img).get('system:time_start'))
       return ee.Number.parse(d.format(viz.dateFormat)).int32()
-    }).getInfo();
+    }).getInfo());
+
     console.log('done computing years');
     console.log(viz.years);
+    console.log(viz)
   }
   
   //Set up time laps object entry
@@ -784,7 +837,7 @@ function addTimeLapseToMap(item,viz,name,visible,label,fontColor,helpBox,whichLa
       if(yr !== viz.years[0]){
         viz.addToLegend = false;
         viz.addToClassLegend = false;
-        
+        viz.classLegendDict = null;
       }
       var vizT = Object.assign({},viz);
       vizT.year = yr
@@ -916,8 +969,21 @@ function addExport(eeImage,name,res,Export,metadataParams,noDataValue){
 
 /////////////////////////////////////////////////////
 //Function to add ee object as well as client-side objects to map
+function getLookupDicts(image,bandName,layerType){
+  if(layerType == 'geeImageCollection'){image = ee.Image(image.first())}
+  if(bandName === null || bandName === undefined){
+    bandName = ee.Image(image).bandNames().getInfo()[0]
+  }
+  values = ee.List([image.get(bandName+'_class_values'),image.get(bandName+'_class_names'),image.get(bandName+'_class_palette')]).getInfo()
+  value_name = zip(values[0],values[1]).map(function(i){return i.join('- ')})
+  // console.log(value_name)
+  legendDict = toObj(value_name,values[2])
+  queryDict = toObj(values[0],value_name)
+  return {'classLegendDict':legendDict,'queryDict':queryDict}
+}
+var typeLookup = {'Image':'geeImage','ImageCollection':'geeImageCollection','Feature':'geeVectorImage','FeatureCollection':'geeVectorImage','Geometry':'geeVectorImage'}
 function addToMap(item,viz,name,visible,label,fontColor,helpBox,whichLayerList,queryItem){
-  
+    
     // $('#layer-list-collapse-label-message').html(`Loading: ${name}`)
     if(viz !== null && viz !== undefined && viz.serialized !== null && viz.serialized !== undefined && viz.serialized === true){
         item = ee.Deserializer.decode(item);
@@ -930,42 +996,58 @@ function addToMap(item,viz,name,visible,label,fontColor,helpBox,whichLayerList,q
     }
     //Possible layerType: geeVector,geoJSONVector,geeImage,geeImageArray,geeImageCollection,tileMapService,dynamicMapService
     if(viz.layerType === null || viz.layerType === undefined){
-      try{var t = item.bandNames();viz.layerType = 'geeImage'}
-      catch(err2){
-        try{
-          var t = ee.Image(item.first()).bandNames().getInfo();
-          // print(t.getInfo())
-          viz.layerType = 'geeImageCollection';
+      console.log(name);
+      var eeType = ee.Algorithms.ObjectType(item).getInfo();
+      if(eeType === 'Feature'){
+        item = ee.FeatureCollection([item])
+        eeType = ee.Algorithms.ObjectType(item).getInfo();
+      }
+      // else if(eeType === 'Geometry'){
+        // showMessage('Error adding ' + name + ' layer',name + ' was found to be a Geometry. Geometries are currently not supported. Please convert to a feature or featureCollection before adding to the map.');
+        // return
+      // }
+      viz.layerType =typeLookup[eeType]; 
+      console.log(eeType)
+      
+      // try{
+      //     var t = ee.Image(item.first()).bandNames().getInfo();
+          
+      //     viz.layerType = 'geeImageCollection';
         
-        }
-        //Check if its a geometry
-        catch(err3){
-          try{
-             var t = item.geometry().getInfo();
+      //   }
+      // catch(err2){
+      //   // console.log(err2)
+      //   try{var t = ee.Image(item).bandNames();console.log(t.getInfo());viz.layerType = 'geeImage'}
+      //   //Check if its a geometry
+      //   catch(err3){
+      //     try{
+      //        var t = item.geometry().getInfo();
             
-          }catch(err4){
-            // console.log('geo');
-            item = ee.FeatureCollection(item);
-            viz.canQuery = false;
-          }
-          //Check if its a feature or featureCollection
-          // try{
-          //   var n = item.limit(501).size().getInfo();
-          //   if(n > 500){
-          //     viz.layerType = 'geeVectorImage';
-          //   }
-          //   // console.log('featureCollection')
-          // }catch(err5){
-          //   // console.log('feature')
-          //   item = ee.FeatureCollection([item])
-          // }
-          viz.layerType = 'geeVector';
-        }
+      //     }catch(err4){
+      //       // console.log('geo');
+      //       item = ee.FeatureCollection(item);
+      //       viz.canQuery = false;
+      //     }
+      //     //Check if its a feature or featureCollection
+      //     // try{
+      //     //   var n = item.limit(501).size().getInfo();
+      //     //   if(n > 500){
+      //     //     viz.layerType = 'geeVectorImage';
+      //     //   }
+      //     //   // console.log('featureCollection')
+      //     // }catch(err5){
+      //     //   // console.log('feature')
+      //     //   item = ee.FeatureCollection([item])
+      //     // }
+      //     viz.layerType = 'geeVector';
+      //   }
         
        
-        }
+      //   }
     }
-  
+    
+    console.log(viz.layerType)
+    // console.log(item.bandNames())
     if(viz.layerType === 'geoJSONVector'){viz.canQuery = false;}
     
     if(viz.layerType === 'geeVector' || viz.layerType === 'geoJSONVector'){
@@ -1048,8 +1130,14 @@ function addToMap(item,viz,name,visible,label,fontColor,helpBox,whichLayerList,q
     layer.queryItem = queryItem;
     layer.layerType = viz.layerType;
 
+    //AutoViz if specified
+    if(viz.autoViz){
+      dicts =getLookupDicts(item,null,viz.layerType)
+      viz.classLegendDict = dicts.classLegendDict;
+      viz.queryDict = dicts.queryDict
+    }
     //Construct legend
-    if(viz != null && viz.bands == null && viz.addToLegend != false && viz.addToClassLegend != true){
+    if(viz != null && viz.bands == null && viz.addToLegend != false && (viz.addToClassLegend === undefined || viz.addToClassLegend === null || viz.addToClassLegend === false) &&(viz.classLegendDict == undefined || viz.classLegendDict == null )){
       addLegendContainer(legendDivID,'legend-'+whichLayerList,false,helpBox)
       
       var legend ={};
@@ -1096,14 +1184,14 @@ function addToMap(item,viz,name,visible,label,fontColor,helpBox,whichLayerList,q
         if(viz.legendLabelRightAfter !== null && viz.legendLabelRightAfter !== undefined){legend.max = viz.max + ' '+ viz.legendLabelRightAfter }
         if(legend.min ==null){legend.min = 'min'};
         if(legend.max ==null){legend.max = 'max'};
-    
-    if(fontColor != null){legend.fontColor = "color:#" +fontColor + ";" }
-        else{legend.fontColor    = "color:#DDD;"}
-     addColorRampLegendEntry(legendDivID,legend)
+   
+      if(fontColor != null){legend.fontColor = "color:#" +fontColor + ";" }
+          else{legend.fontColor    = "color:#DDD;"}
+       addColorRampLegendEntry(legendDivID,legend)
     }
 
-    else if(viz != null && viz.bands == null && viz.addToClassLegend == true){
-
+    else if(viz != null && viz.bands == null  &&  ((viz.classLegendDict !== undefined  &&  viz.classLegendDict !== null) || viz.addToClassLegend === true)){
+      
       addLegendContainer(legendDivID,'legend-'+whichLayerList,false,helpBox)
       var classLegendContainerID = legendDivID + '-class-container';
       var legendClassContainerName;
@@ -1177,10 +1265,12 @@ function standardTileURLFunction(url,xThenY,fileExtension,token){
               if(fileExtension === null || fileExtension === undefined  ){fileExtension  = '.png';}
               
               return function(coord, zoom) {
+                    
                     // "Wrap" x (logitude) at 180th meridian properly
                     // NB: Don't touch coord.x because coord param is by reference, and changing its x property breakes something in Google's lib 
                     var tilesPerGlobe = 1 << zoom;
                     var x = coord.x % tilesPerGlobe;
+                    console.log(coord,zoom,x)
                     if (x < 0) {
                         x = tilesPerGlobe+x;
                     }
@@ -1193,6 +1283,7 @@ function standardTileURLFunction(url,xThenY,fileExtension,token){
                     
                 }
             }
+function superSimpleTileURLFunction(url){return function(coord, zoom) {return url + zoom+'/' + coord.y+'/'+coord.x}}
 /////////////////////////////////////////////////////
 //Function to add ee object ot map
 function addRESTToMap(tileURLFunction,name,visible,maxZoom,helpBox,whichLayerList){
@@ -1449,7 +1540,12 @@ function reRun(){
   
 
   //Rerun the GEE code
-  setTimeout(function() { run();  $('#close-modal-button').click();setupAreaLayerSelection();}, 1500);
+  setTimeout(function() { 
+    run();  
+    $('#close-modal-button').click();
+    setupAreaLayerSelection();
+    addLabelOverlay();
+  }, 1500);
 	
   
   
@@ -1927,7 +2023,7 @@ function dropdownUpdateStudyArea(whichOne){
   var coords = studyAreaDict[whichOne].center;
   centerMap(coords[1],coords[0],coords[2]);
     if(mode === 'Ancillary'){
-      run = runSimple;
+      run = runAncillary;
     } else if( mode === 'LT'){
       run  = runLT;
     }else if( mode === 'LCMS'|| (mode === 'LCMS-pilot' && studyAreaDict[longStudyAreaName].isPilot == false)){
@@ -2094,228 +2190,84 @@ function getInfoWindow(xOffset,yOffset){
     close:false
   });
 } 
+//Functions for tracking views and going forward and backward map views
+function trackView(){
+  if(updateViewList){
+    viewList = viewList.slice(0,viewIndex)
+    viewList.push({lng:urlParams.lng, lat:urlParams.lat,zoom:urlParams.zoom});
+    viewIndex = viewList.length;
+    checkViewIndex();
+  }
+}
+//See if there are any remaining views
+function checkViewIndex(){
+  if(viewIndex <= 1){
+    viewIndex = 1
+    $('#back-view-button').prop('disabled',true);
+  }else{$('#back-view-button').prop('disabled',false)};
+
+  if(viewIndex >= viewList.length){
+    viewIndex = viewList.length;
+    $('#forward-view-button').prop('disabled',true);
+  }else{$('#forward-view-button').prop('disabled',false)};
+}
+function setView(view){
+    updateViewList = false;
+    map.setCenter(view);
+    map.setZoom(view.zoom);
+  }
+  function backView(){
+    viewIndex--;
+    checkViewIndex();
+    setView(viewList[viewIndex-1]);
+    
+  }
+  function forwardView(){
+    viewIndex++;
+    checkViewIndex();
+    setView(viewList[viewIndex-1]);
+    
+  } 
 ////////////////////////////////////////////////////////////////
+// Create an overlay to display map labels only
+var labelOverlayAdded = false;
+function addLabelOverlay(){
+  map.overlayMapTypes.setAt(Object.keys(layerObj).length, labelsMapType);
+  labelOverlayAdded = true;
+}
+function removeLabelOverlay(){
+  map.overlayMapTypes.setAt(Object.keys(layerObj).length,null);
+  labelOverlayAdded = false;
+}
+function toggleLabelOverlay(){
+  if(labelOverlayAdded){
+    removeLabelOverlay()
+  }else{addLabelOverlay()}
+}
+var labelsMapType;
+
 //Initialize map
 function initialize() {
-  // Create a new StyledMapType object, passing it an array of styles,
-  // and the name to be displayed on the map type control.
-
-  //Created with: https://mapstyle.withgoogle.com/
-  var styledMapType = new google.maps.StyledMapType(
-    [
+  labelsMapType = new google.maps.StyledMapType([
+  {
+    "elementType": "geometry.fill",
+    "stylers": [
       {
-        "elementType": "geometry",
-        "stylers": [
-          {
-            "color": "#212121"
-          }
-        ]
-      },
-      {
-        "elementType": "labels.icon",
-        "stylers": [
-          {
-            "visibility": "off"
-          }
-        ]
-      },
-      {
-        "elementType": "labels.text.fill",
-        "stylers": [
-          {
-            "color": "#757575"
-          }
-        ]
-      },
-      {
-        "elementType": "labels.text.stroke",
-        "stylers": [
-          {
-            "color": "#212121"
-          }
-        ]
-      },
-      {
-        "featureType": "administrative",
-        "elementType": "geometry",
-        "stylers": [
-          {
-            "color": "#757575"
-          }
-        ]
-      },
-      {
-        "featureType": "administrative.country",
-        "elementType": "labels.text.fill",
-        "stylers": [
-          {
-            "color": "#9e9e9e"
-          }
-        ]
-      },
-      {
-        "featureType": "administrative.land_parcel",
-        "stylers": [
-          {
-            "visibility": "off"
-          }
-        ]
-      },
-      {
-        "featureType": "administrative.locality",
-        "elementType": "labels.text.fill",
-        "stylers": [
-          {
-            "color": "#bdbdbd"
-          }
-        ]
-      },
-      {
-        "featureType": "poi",
-        "elementType": "labels.text.fill",
-        "stylers": [
-          {
-            "color": "#757575"
-          }
-        ]
-      },
-      {
-        "featureType": "poi.park",
-        "elementType": "geometry",
-        "stylers": [
-          {
-            "color": "#181818"
-          }
-        ]
-      },
-      {
-        "featureType": "poi.park",
-        "elementType": "geometry.fill",
-        "stylers": [
-          {
-            "color": "#004000"
-          }
-        ]
-      },
-      {
-        "featureType": "poi.park",
-        "elementType": "labels.icon",
-        "stylers": [
-          {
-            "color": "#004000"
-          }
-        ]
-      },
-      {
-        "featureType": "poi.park",
-        "elementType": "labels.text",
-        "stylers": [
-          {
-            "color": "#004000"
-          }
-        ]
-      },
-      {
-        "featureType": "poi.park",
-        "elementType": "labels.text.fill",
-        "stylers": [
-          {
-            "color": "#616161"
-          }
-        ]
-      },
-      {
-        "featureType": "poi.park",
-        "elementType": "labels.text.stroke",
-        "stylers": [
-          {
-            "color": "#1b1b1b"
-          }
-        ]
-      },
-      {
-        "featureType": "road",
-        "elementType": "geometry.fill",
-        "stylers": [
-          {
-            "color": "#2c2c2c"
-          }
-        ]
-      },
-      {
-        "featureType": "road",
-        "elementType": "labels.text.fill",
-        "stylers": [
-          {
-            "color": "#8a8a8a"
-          }
-        ]
-      },
-      {
-        "featureType": "road.arterial",
-        "elementType": "geometry",
-        "stylers": [
-          {
-            "color": "#373737"
-          }
-        ]
-      },
-      {
-        "featureType": "road.highway",
-        "elementType": "geometry",
-        "stylers": [
-          {
-            "color": "#3c3c3c"
-          }
-        ]
-      },
-      {
-        "featureType": "road.highway.controlled_access",
-        "elementType": "geometry",
-        "stylers": [
-          {
-            "color": "#4e4e4e"
-          }
-        ]
-      },
-      {
-        "featureType": "road.local",
-        "elementType": "labels.text.fill",
-        "stylers": [
-          {
-            "color": "#616161"
-          }
-        ]
-      },
-      {
-        "featureType": "transit",
-        "elementType": "labels.text.fill",
-        "stylers": [
-          {
-            "color": "#757575"
-          }
-        ]
-      },
-      {
-        "featureType": "water",
-        "elementType": "geometry",
-        "stylers": [
-          {
-            "color": "#000000"
-          }
-        ]
-      },
-      {
-        "featureType": "water",
-        "elementType": "labels.text.fill",
-        "stylers": [
-          {
-            "color": "#3d3d3d"
-          }
-        ]
+        "visibility": "off"
       }
-    ],
-            {name: 'Dark Mode'});
+    ]
+  },
+  {
+    "elementType": "geometry.stroke",
+    "stylers": [
+      {
+        "weight": 0.01
+      }
+    ]
+  }
+]);
+
+ 
   var mapTypeIds = ['roadmap', 'satellite', 'hybrid', 'terrain'];
   if(urlParams.mapTypeId  === undefined || urlParams.mapTypeId  === null &&urlParams.mapTypeId.indexOf(urlParams.mapTypeIds)  === -1 ){
     urlParams.mapTypeId = 'hybrid'
@@ -2352,7 +2304,7 @@ function initialize() {
   //Set up caching of study area
   if(typeof(Storage) !== "undefined"){
     cachedStudyAreaName = localStorage.getItem("cachedStudyAreaName");
-    console.log(urlParams.studyAreaName)
+    // console.log(urlParams.studyAreaName)
 
     if(urlParams.studyAreaName !== null && urlParams.studyAreaName !== undefined){
       cachedStudyAreaName = decodeURIComponent(urlParams.studyAreaName);
@@ -2385,6 +2337,8 @@ function initialize() {
     mapOptions.center = {lng:parseFloat(urlParams.lng),lat:parseFloat(urlParams.lat)};
   }else{
     mapOptions.center = center;
+
+
   }
   if(urlParams.zoom !== undefined && urlParams.zoom !== null ){
     print('Setting zoom from URL')
@@ -2392,12 +2346,34 @@ function initialize() {
   }else{
     mapOptions.zoom = zoom;
   }
-  
-     
+  urlParams.lng =  mapOptions.center.lng;urlParams.lat = mapOptions.center.lat;urlParams.zoom= mapOptions.zoom;
+  // trackView()  
   map = new google.maps.Map(document.getElementById("map"),mapOptions);
   //Associate the styled map with the MapTypeId and set it to display.
-  map.mapTypes.set('dark_mode', styledMapType);
-  
+  // map.mapTypes.set('dark_mode', styledMapType);
+  // const drawingManager = new google.maps.drawing.DrawingManager({
+  //   drawingMode: google.maps.drawing.OverlayType.MARKER,
+  //   drawingControl: true,
+  //   drawingControlOptions: {
+  //     position: google.maps.ControlPosition.TOP_CENTER,
+  //     drawingModes: [
+   
+  //       google.maps.drawing.OverlayType.RECTANGLE,
+  //       google.maps.drawing.OverlayType.POLYGON,
+        
+  //     ],
+  //   },
+    
+    
+  // });
+  // drawingManager.setMap(map);
+ //  $("#rectangle-drawing-btn").click( function(){
+ //      drawingManager.setDrawingMode(google.maps.drawing.OverlayType.RECTANGLE);
+ // });
+
+ //  $("#polygon-drawing-btn")square-drawing-btn.click( function(){
+ //        drawingManager.setDrawingMode(google.maps.drawing.OverlayType.POLYGON);
+ //   });
   //Listen for street view use
   //Adapted from: https://stackoverflow.com/questions/7251738/detecting-google-maps-streetview-mode
   var thePanorama = map.getStreetView();
@@ -2536,24 +2512,15 @@ function initialize() {
         else{updateMousePositionAndZoom(mouseLng,mouseLat,zoom,lastElevation)}
         
     })
-    //Listen for zoom change and update bottom bar
-    google.maps.event.addListener(map,'zoom_changed',function(){
-        var zoom = map.getZoom();
-        console.log('zoom changed')
-        updateMousePositionAndZoom(mouseLng,mouseLat,zoom,lastElevation)
-    })
-    google.maps.event.addListener(map,'maptypeid_changed',function(){
-        console.log('map type id changed')
-        urlParams.mapTypeId = map.mapTypeId;
-    })
-
-    //Keep track of map bounds for eeBoundsPoly object 
-    google.maps.event.addListener(map,'bounds_changed',function(){
+    function trackViewChange(){
+      // console.log('idle')
       zoom = map.getZoom();
       var mapCenter = map.getCenter();
       var mapCenterLng = mapCenter.lng();
       var mapCenterLat = mapCenter.lat();
       urlParams.lng = mapCenterLng;urlParams.lat = mapCenterLat;urlParams.zoom= zoom;
+
+      trackView();
       
       // console.log('bounds changed');
       var bounds = map.getBounds();
@@ -2561,10 +2528,25 @@ function initialize() {
       var keysX = Object.keys(bounds[keys[0]]);
       var keysY = Object.keys(bounds[keys[1]]);
       // console.log('b');console.log(bounds);
+      updateMousePositionAndZoom(mouseLng,mouseLat,zoom,lastElevation);
       eeBoundsPoly = ee.Geometry.Rectangle([bounds[keys[1]][keysX[0]],bounds[keys[0]][keysY[0]],bounds[keys[1]][keysX[1]],bounds[keys[0]][keysY[1]]]);
-        if(typeof(Storage) == "undefined") return;
-        localStorage.setItem(cachedSettingskey,JSON.stringify({center:{lat:mapCenter.lat(),lng:mapCenter.lng()},zoom:zoom}));
-      });
+      if(typeof(Storage) == "undefined") return;
+      localStorage.setItem(cachedSettingskey,JSON.stringify({center:{lat:mapCenterLat,lng:mapCenterLng},zoom:zoom}));
+      updateViewList = true;
+      // setTimeout(function(){updateViewList = true;},10)
+    }
+    //Listen for zoom change and update bottom bar
+    
+    google.maps.event.addListener(map,'maptypeid_changed',function(){
+        console.log('map type id changed')
+        urlParams.mapTypeId = map.mapTypeId;
+        if(map.mapTypeId === 'satellite'){removeLabelOverlay()}
+        else{addLabelOverlay()};
+    })
+
+    //Keep track of map bounds and zoom changes
+    // google.maps.event.addListener(map,'zoom_changed',trackViewChange)
+    google.maps.event.addListener(map,'idle',trackViewChange);
 
     //Specify proxy server location
     //Proxy server used for EE and GCS auth
@@ -2587,7 +2569,7 @@ function initialize() {
         $('#study-area-label').text(defaultStudyArea);
       }
       if(mode === 'Ancillary'){
-        run = runSimple;
+        run = runAncillary;
       } else if( mode === 'LCMS'|| (mode === 'LCMS-pilot' && studyAreaDict[longStudyAreaName].isPilot == false)){
         run  = runGTAC;
       }else if( mode === 'LT'){
@@ -2631,7 +2613,7 @@ function initialize() {
       $('#close-modal-button').click();
       $('#intro-modal-loading-div').hide();
       $('#summary-spinner').hide();
-      
+      addLabelOverlay();
     }, 1500);
    
   	});
